IQR Demo Search Application
===========================
Requires two servers: this server for the client/server interface and the IQR
RESTful service server to provide IQR functionality.

Until tested otherwise, both servers should be run on the same machine with
different ports in order to avoid CORS issues.
